..
    This file is part of hepcrawl.
    Copyright (C) 2015, 2016, 2017 CERN.

    hepcrawl is a free software; you can redistribute it and/or modify it
    under the terms of the Revised BSD License; see LICENSE file for
    more details.

Changelog
---------

Here you can find the `full changelog for this version`_

.. _full changelog for this version: _static/CHANGELOG.txt

